Houdini.py
==========

A Python binding for Houdini_ that provides (un)escaping functions
for HTML, URLs/URIs and Javascript.

.. _Houdini: https://github.com/tanoku/houdini


Installation
------------

With pip::

    pip install houdini.py

Or manually::

    python setup.py install
